var group__link =
[
    [ "Bonding", "group__bonding.html", "group__bonding" ],
    [ "Bridging", "group__bridge.html", "group__bridge" ],
    [ "CAN", "group__can.html", "group__can" ],
    [ "Dummy", "group__dummy.html", null ],
    [ "Geneve", "group__geneve.html", "group__geneve" ],
    [ "IP6GRE", "group__ip6gre.html", "group__ip6gre" ],
    [ "IP6TNL", "group__ip6tnl.html", "group__ip6tnl" ],
    [ "IP6VTI", "group__ip6vti.html", "group__ip6vti" ],
    [ "IPGRE", "group__ipgre.html", "group__ipgre" ],
    [ "IPIP", "group__ipip.html", "group__ipip" ],
    [ "IPVLAN", "group__ipvlan.html", "group__ipvlan" ],
    [ "IPVTI", "group__ipvti.html", "group__ipvti" ],
    [ "Intermediate Functional Block", "group__ifb.html", null ],
    [ "Link Modules API", "group__link__API.html", "group__link__API" ],
    [ "MACVLAN/MACVTAP", "group__macvlan.html", "group__macvlan" ],
    [ "MACsec", "group__macsec.html", "group__macsec" ],
    [ "PPP", "group__ppp.html", "group__ppp" ],
    [ "SIT", "group__sit.html", "group__sit" ],
    [ "SRIOV", "group__sriov.html", "group__sriov" ],
    [ "Team", "group__team.html", "group__team" ],
    [ "VETH", "group__veth.html", "group__veth" ],
    [ "VLAN", "group__vlan.html", "group__vlan" ],
    [ "VRF", "group__vrf.html", "group__vrf" ],
    [ "VXLAN", "group__vxlan.html", "group__vxlan" ],
    [ "XFRMI", "group__xfrmi.html", "group__xfrmi" ],
    [ "rtnl_link", "structrtnl__link.html", null ],
    [ "rtnl_link_stat_id_t", "group__link.html#gabe368ecaa2f41e8392325b8060862ba6", [
      [ "RTNL_LINK_RX_PACKETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ae24e248204a9622dcc1d3ca765e4ff2c", null ],
      [ "RTNL_LINK_TX_PACKETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ae96964ee9fa6649c4a6e262ebbaa4209", null ],
      [ "RTNL_LINK_RX_BYTES", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a6fff847df4f4e109545eadf1c4ea96e4", null ],
      [ "RTNL_LINK_TX_BYTES", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a73ac856deb1fec40c86c741a19d94e02", null ],
      [ "RTNL_LINK_RX_ERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a59d5c659780373cc6743791da1b04da7", null ],
      [ "RTNL_LINK_TX_ERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ace59816f3e69fb50f5e96ad687a9995e", null ],
      [ "RTNL_LINK_RX_DROPPED", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a4b7991282d11ef2a6e3f99e4c81c2f5f", null ],
      [ "RTNL_LINK_TX_DROPPED", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a22376cc9f8c823fab7fadd2236744704", null ],
      [ "RTNL_LINK_RX_COMPRESSED", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a0d68a77fdca632afdf9f6bf22f584c2f", null ],
      [ "RTNL_LINK_TX_COMPRESSED", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a55f2d6c48a7b3228aa81fdbcaa3df598", null ],
      [ "RTNL_LINK_RX_FIFO_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a55470901b6de5af731b416b55fee3922", null ],
      [ "RTNL_LINK_TX_FIFO_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6aca965e8b1ba6a185e218ca9a7cc0de43", null ],
      [ "RTNL_LINK_RX_LEN_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a14878785a163a5d641365ad1fe989e30", null ],
      [ "RTNL_LINK_RX_OVER_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ab5c24b10db0f23b42ec53b35c0ce78c7", null ],
      [ "RTNL_LINK_RX_CRC_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a627b99407a003beacc4650e4bf6ba8a7", null ],
      [ "RTNL_LINK_RX_FRAME_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ad770fd1b2f109dbde0e6abb47a48efce", null ],
      [ "RTNL_LINK_RX_MISSED_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a97beb3930dfd2b6169b84503c64fec09", null ],
      [ "RTNL_LINK_TX_ABORT_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ac0bb365dde65bf6d2e59879d001830b5", null ],
      [ "RTNL_LINK_TX_CARRIER_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a86b40767facc5e9b3a0aa1234a1aba24", null ],
      [ "RTNL_LINK_TX_HBEAT_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a68d92628905bcd0efa6c767cf69839fc", null ],
      [ "RTNL_LINK_TX_WIN_ERR", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ad978ea07614ed5de02de33c0d15ef94e", null ],
      [ "RTNL_LINK_COLLISIONS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a04284097eb3da39bc7a1607f79102391", null ],
      [ "RTNL_LINK_MULTICAST", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ac45051e0af652cb329b49ced518ae926", null ],
      [ "RTNL_LINK_IP6_INPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a4a0fa3396695310150ef41fbf281db22", null ],
      [ "RTNL_LINK_IP6_INHDRERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a784a63cfdbc253bf181391ec56122782", null ],
      [ "RTNL_LINK_IP6_INTOOBIGERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6acecf1e8fbe8a4bc1a053f209063e9329", null ],
      [ "RTNL_LINK_IP6_INNOROUTES", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a159e22d1d42a4522c54cad2036439a81", null ],
      [ "RTNL_LINK_IP6_INADDRERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ac4190f0905ced28f448ecf18258aaddd", null ],
      [ "RTNL_LINK_IP6_INUNKNOWNPROTOS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a491baac7ec6bccced8732addc115fad8", null ],
      [ "RTNL_LINK_IP6_INTRUNCATEDPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a128581c9828ae48ceb327b43c09a15b7", null ],
      [ "RTNL_LINK_IP6_INDISCARDS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a9bce776cdfae2ec6eef973f32b30b717", null ],
      [ "RTNL_LINK_IP6_INDELIVERS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a1f7602934abd0525d71a5146a669f8b9", null ],
      [ "RTNL_LINK_IP6_OUTFORWDATAGRAMS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a9a200aa90c051e82cb0a5cfb25864559", null ],
      [ "RTNL_LINK_IP6_OUTPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a34fb40303adb60def0870e1e4fcd25e0", null ],
      [ "RTNL_LINK_IP6_OUTDISCARDS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ab04a8ebadb3881b9785574bb97e6f5de", null ],
      [ "RTNL_LINK_IP6_OUTNOROUTES", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6aa6bd849ad3204ddb3c323e2fe82c88f0", null ],
      [ "RTNL_LINK_IP6_REASMTIMEOUT", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a3013c3003e904d119fd11f10fb1a03ce", null ],
      [ "RTNL_LINK_IP6_REASMREQDS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a7f82eb841a6c38cfdca48d2e983a786b", null ],
      [ "RTNL_LINK_IP6_REASMOKS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a1a38a7d17661e62f3c2481f153a872af", null ],
      [ "RTNL_LINK_IP6_REASMFAILS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6af59bc80bacbb42748c6a1f73049d9207", null ],
      [ "RTNL_LINK_IP6_FRAGOKS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6af291d40ea4bf0b848f05662a2d1848f6", null ],
      [ "RTNL_LINK_IP6_FRAGFAILS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a37cda11d1196b193461412fdbc842c0a", null ],
      [ "RTNL_LINK_IP6_FRAGCREATES", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ab47e35a10611783755e1d9f2ac04bf72", null ],
      [ "RTNL_LINK_IP6_INMCASTPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a189e009960541d3a83e6ff54f4ff0f06", null ],
      [ "RTNL_LINK_IP6_OUTMCASTPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ae9f6861a714c37819e665f6b419d9d16", null ],
      [ "RTNL_LINK_IP6_INBCASTPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a53f502e64d102529602df758bf7f5aaa", null ],
      [ "RTNL_LINK_IP6_OUTBCASTPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6aeb1d3f00638703b01f51cc373a4a44b9", null ],
      [ "RTNL_LINK_IP6_INOCTETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a6ace825b2f98cd2bd8de68d4481197d0", null ],
      [ "RTNL_LINK_IP6_OUTOCTETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a36c8adc66159b31d5aa345ca8f2dc48c", null ],
      [ "RTNL_LINK_IP6_INMCASTOCTETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6abb544ae6c745ca497f3bf3d0786b2724", null ],
      [ "RTNL_LINK_IP6_OUTMCASTOCTETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a172dd990d95bbe366d7738295cb5e9b7", null ],
      [ "RTNL_LINK_IP6_INBCASTOCTETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a0763ac0be3194cccd4e54cd01c5b8b9b", null ],
      [ "RTNL_LINK_IP6_OUTBCASTOCTETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a1b22fdba403c262e7eee4833d192ed77", null ],
      [ "RTNL_LINK_ICMP6_INMSGS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a14a3b065c83fe34fdceccc42402d14ae", null ],
      [ "RTNL_LINK_ICMP6_INERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a37288e4aeb2bce77225d48dd6ec72f69", null ],
      [ "RTNL_LINK_ICMP6_OUTMSGS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a444e85b40a858729641eb7ee198a3d5b", null ],
      [ "RTNL_LINK_ICMP6_OUTERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ab52b4962f052aa4cf2e01a864c28d080", null ],
      [ "RTNL_LINK_ICMP6_CSUMERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a4930c531e01e8257e1757ae1215da3cf", null ],
      [ "RTNL_LINK_IP6_CSUMERRORS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a455ed79a339d271b7b947ac06b90cb07", null ],
      [ "RTNL_LINK_IP6_NOECTPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a9ea1025543be09acdf5ad96227dfa5d6", null ],
      [ "RTNL_LINK_IP6_ECT1PKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ac6306b0fc48389db440aea0f5fb5f7c0", null ],
      [ "RTNL_LINK_IP6_ECT0PKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a0cef9de8266916162c6e242b1e950a4f", null ],
      [ "RTNL_LINK_IP6_CEPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a4cfaee4676aad12a62f5977070028484", null ],
      [ "RTNL_LINK_RX_NOHANDLER", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a6dbb2cde7fb56a637be417cd0151449a", null ],
      [ "RTNL_LINK_REASM_OVERLAPS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a0dbde66784affe342ea9cd39472ea325", null ]
    ] ],
    [ "rtnl_link_alloc_cache_flags", "group__link.html#gaa38fce4b34b6c84f9f84174c09764b2e", null ],
    [ "rtnl_link_alloc_cache", "group__link.html#ga8fdeaee0a6f872d19e72cd77c141ce73", null ],
    [ "rtnl_link_get", "group__link.html#ga9c88cc572d0d737ea2f9370c45d4f017", null ],
    [ "rtnl_link_get_by_name", "group__link.html#ga89feb39f7f98a0c308116c60ea211526", null ],
    [ "rtnl_link_build_get_request", "group__link.html#gaf0009632298406b7f1c1ccb5186d1eb8", null ],
    [ "rtnl_link_get_kernel", "group__link.html#ga96807a247568145dd99f351ded0ec7cb", null ],
    [ "rtnl_link_i2name", "group__link.html#gac1af6b95764928a570861d9b2937adbe", null ],
    [ "rtnl_link_name2i", "group__link.html#ga8de66ce556b6d23f045fbc6079d547ed", null ],
    [ "rtnl_link_build_add_request", "group__link.html#ga73a9ad02daafd2051e97baf9cd995a35", null ],
    [ "rtnl_link_add", "group__link.html#ga010cb3c6c598f7a60f97b67b8df9b227", null ],
    [ "rtnl_link_build_change_request", "group__link.html#ga5ed9fb9346ff6c922de483ba37493889", null ],
    [ "rtnl_link_change", "group__link.html#gaff7c3644e10230ba3449bc35a064e935", null ],
    [ "rtnl_link_build_delete_request", "group__link.html#gab78ac08b353c159b69282cd25185766a", null ],
    [ "rtnl_link_delete", "group__link.html#ga591bcb3fbb7a19a4f40cfd45d060aede", null ],
    [ "rtnl_link_alloc", "group__link.html#ga30f2f032a6ce6604eb01978c1d62994a", null ],
    [ "rtnl_link_put", "group__link.html#gad4c047c313cc2d6b84943707f37509c4", null ],
    [ "rtnl_link_set_name", "group__link.html#ga7cce5e6bea4df62c78948e94398ec6f9", null ],
    [ "rtnl_link_get_name", "group__link.html#ga9ce15fdb7b0f3c065f247538347e5cdb", null ],
    [ "rtnl_link_set_group", "group__link.html#ga93d589812952193573584da4bf81e719", null ],
    [ "rtnl_link_get_group", "group__link.html#ga4cee184275214c9e5f21901e9a31cf31", null ],
    [ "rtnl_link_set_addr", "group__link.html#ga31fef8ebdb0b127dba77e5c0e79a8c9b", null ],
    [ "rtnl_link_get_addr", "group__link.html#gaf2e2eb2face11adba278982322248394", null ],
    [ "rtnl_link_set_broadcast", "group__link.html#ga01d020131dfc82276a734d98db6a49af", null ],
    [ "rtnl_link_get_broadcast", "group__link.html#ga5a9e829c8c7408ebd23c0586d61556c3", null ],
    [ "rtnl_link_set_flags", "group__link.html#ga9a43f1fdc2397eedeb7190e9ea0b4e47", null ],
    [ "rtnl_link_unset_flags", "group__link.html#ga40c02d4d30f07243093faa3279f57ed3", null ],
    [ "rtnl_link_get_flags", "group__link.html#gafcf6bb7515e5fa4915ec0194b046a4af", null ],
    [ "rtnl_link_set_family", "group__link.html#gac3d6d355daaba562b8b07066ad346a20", null ],
    [ "rtnl_link_get_family", "group__link.html#ga93dac91665467d374beb3cbe1b4e1ca2", null ],
    [ "rtnl_link_set_arptype", "group__link.html#ga3faf1a01287bed0d30bca55b7eef6394", null ],
    [ "rtnl_link_get_arptype", "group__link.html#ga901562c2300590ff75005e02fc652387", null ],
    [ "rtnl_link_set_ifindex", "group__link.html#gaf204fa0a17dedbac283d3955cf21f608", null ],
    [ "rtnl_link_get_ifindex", "group__link.html#gafd48d0b99697235ce3c8217a4664b135", null ],
    [ "rtnl_link_set_mtu", "group__link.html#ga15064719789d110959eb79809746c128", null ],
    [ "rtnl_link_get_mtu", "group__link.html#gaecd466ecfef90609f30c3ee8f67ecd37", null ],
    [ "rtnl_link_set_txqlen", "group__link.html#gaefe933675754615d39f2d5aae0ead539", null ],
    [ "rtnl_link_get_txqlen", "group__link.html#ga9c9cd6922b1825003ff2674a20fdeb0e", null ],
    [ "rtnl_link_set_link_netnsid", "group__link.html#ga1a4e4bdabe0c5eea16ce4c9d6663074b", null ],
    [ "rtnl_link_get_link_netnsid", "group__link.html#gafcb48aa44a27decd2ff7c2cc0e1cbb79", null ],
    [ "rtnl_link_set_master", "group__link.html#gae538e896372b12347daac1dd50fd3f9d", null ],
    [ "rtnl_link_get_master", "group__link.html#ga0efbecffaca6d12e029e023524d17fbc", null ],
    [ "rtnl_link_set_carrier", "group__link.html#ga02314a373d30e7534afc8fb9907c67fc", null ],
    [ "rtnl_link_get_carrier", "group__link.html#gaca6eb0b6da5e6c38d5237d20500e8a6c", null ],
    [ "rtnl_link_get_carrier_changes", "group__link.html#gaf42d691a912f8e68a3a2ae859030c613", null ],
    [ "rtnl_link_set_operstate", "group__link.html#gab87182565798e51c151097d72768492c", null ],
    [ "rtnl_link_get_operstate", "group__link.html#ga5881f6b39e545bbca94c307b71962e90", null ],
    [ "rtnl_link_set_linkmode", "group__link.html#ga4742bdbe9e75ce816ff1d940d6f5ec0e", null ],
    [ "rtnl_link_get_linkmode", "group__link.html#ga0424ab2b9ee65104b409695e6d6b65c3", null ],
    [ "rtnl_link_get_ifalias", "group__link.html#gadffd8eea15ce2e3350a842209adf0477", null ],
    [ "rtnl_link_set_ifalias", "group__link.html#ga6307c4ef261f91bb2a0e530b020aea5d", null ],
    [ "rtnl_link_set_qdisc", "group__link.html#ga9c6a0c9b0d439afaf55b35775f8b2693", null ],
    [ "rtnl_link_get_qdisc", "group__link.html#ga8087cba9daf19eb66eef6acddfd52f01", null ],
    [ "rtnl_link_get_num_vf", "group__link.html#ga5c704e61b158a1a4b54430717157f672", null ],
    [ "rtnl_link_get_stat", "group__link.html#ga0c0c6a88a7113d7727c647c003bb6fab", null ],
    [ "rtnl_link_set_stat", "group__link.html#ga9ecc6200058764b01df84c1a479fb546", null ],
    [ "rtnl_link_set_type", "group__link.html#gad9f953f44e65c3deb519edad1344fb71", null ],
    [ "rtnl_link_get_type", "group__link.html#ga7f00e216e9779ea11b25b391dbcdb024", null ],
    [ "rtnl_link_set_slave_type", "group__link.html#ga5cec4fbac79ed555de5e306d3fd2e424", null ],
    [ "rtnl_link_get_slave_type", "group__link.html#ga54b51f0a9f3d4d9b851b97778dea2f84", null ],
    [ "rtnl_link_set_promiscuity", "group__link.html#gabb8d59e73563553d4dd64ab0b20ff852", null ],
    [ "rtnl_link_get_promiscuity", "group__link.html#ga677414c60bafcc0a598e08d458b58ed6", null ],
    [ "rtnl_link_set_num_tx_queues", "group__link.html#ga6f54a699e6ea6216918a5cf35398b1f0", null ],
    [ "rtnl_link_get_num_tx_queues", "group__link.html#ga4bdca1d925f79c7bd08e6ebc729d3f2a", null ],
    [ "rtnl_link_set_num_rx_queues", "group__link.html#ga84d340783b45e8a03889b20eb4e05228", null ],
    [ "rtnl_link_get_num_rx_queues", "group__link.html#ga202c65c18d9708af6eb29f2a68dc4b8c", null ],
    [ "rtnl_link_get_gso_max_segs", "group__link.html#gabe5e84651f8d5a7644658f7e889f816d", null ],
    [ "rtnl_link_get_gso_max_size", "group__link.html#gae0ffc1b177e7a9ce6136eafefeab6e9e", null ],
    [ "rtnl_link_get_phys_port_id", "group__link.html#ga533f575b85ec7be1741c9f3b23ce0bce", null ],
    [ "rtnl_link_get_phys_port_name", "group__link.html#ga5e854dbd4a2b8fcbd9321a88bede79c6", null ],
    [ "rtnl_link_enslave_ifindex", "group__link.html#gab5bb2464cf64a566db03d5ce8e11d80e", null ],
    [ "rtnl_link_enslave", "group__link.html#gab97ffb9d3b8e9899e6a9d1a31ef2ecb5", null ],
    [ "rtnl_link_release_ifindex", "group__link.html#ga289ee60ccfe070649d702b007f68b94c", null ],
    [ "rtnl_link_release", "group__link.html#ga00fd70d9a966b66cefcf4d716dc8caa0", null ],
    [ "rtnl_link_set_info_type", "group__link.html#gadddd34902ec52fa8674f66a2cd99fa9f", null ],
    [ "rtnl_link_get_info_type", "group__link.html#gaa71f3239aadc7cce5a633f06a176dde8", null ],
    [ "rtnl_link_set_weight", "group__link.html#ga620a899abab144ac472405706c3159a6", null ],
    [ "rtnl_link_get_weight", "group__link.html#ga203d15a3c54d628f09b1b9b8144c37d6", null ]
];